<?php

namespace FiloBlu\StockaFix\Helper;

/**
 * Class MailHelper
 * @package FiloBlu\StockaFix\Helper
 */
class MailHelper
{

    /**
     * @var \FiloBlu\StockaFix\Mail\Template\TransportBuilder
     */
    protected $transportBuilder;

    /**
     * @var \Magento\Framework\Translate\Inline\StateInterface
     */
    protected $inlineTranslation;

    /**
     * MailHelper constructor.
     * @param \FiloBlu\StockaFix\Mail\Template\TransportBuilder $transportBuilder
     * @param \Magento\Framework\Translate\Inline\StateInterface $inlineTranslation
     */
    public function __construct(
        \FiloBlu\StockaFix\Mail\Template\TransportBuilder $transportBuilder,
        \Magento\Framework\Translate\Inline\StateInterface $inlineTranslation
    )
    {
        $this->transportBuilder = $transportBuilder;
        $this->inlineTranslation = $inlineTranslation;
    }

    /**
     *
     * @param array $to ['email' => "email@sender.com", 'name' => 'Name of Sender'];
     * @param string $templateIdentifier
     * @param array $templateVars ['report_name' => '...', 'report_count' => '...']
     * @param array $attachments ['file1.csv', 'file2.csv']
     *
     * @throws \Magento\Framework\Exception\MailException
     */
    public function sendReportMail(array $to, $attachments = [], $templateVars = [], $templateIdentifier = 'filoblu_stockafix_report_template')
    {
        $templateOptions = [
            'area' => \Magento\Framework\App\Area::AREA_ADMINHTML,
            'store' => \Magento\Store\Model\Store::DEFAULT_STORE_ID
        ];

        $from = ['email' => "smtp@filoblu.com", 'name' => 'smtp@filoblu.com'];

        $this->inlineTranslation->suspend();
        $transport = $this->transportBuilder
            ->setTemplateIdentifier($templateIdentifier)
            ->setTemplateOptions($templateOptions)
            ->setTemplateVars($templateVars)
            ->setFrom($from)
            ->addTo($to)
            ->getTransport();

        foreach ($attachments as $attachment) {
            $body = base64_encode(file_get_contents($attachment));
            $this->transportBuilder->addAttachment($body);
        }

        $transport->sendMessage();
        $this->inlineTranslation->resume();
    }

}
